---
title: <span class="badge object-type-scalar"></span> Lumens
---
# <span class="badge object-type-scalar"></span> Lumens

Energy: Lumens (Lm)

## Definition

```python
# Energy: Lumens (Lm)
Lumens: typing.Literal["lumens"] = "lumens"
```
